pub struct SetAppointmentResponse {
pub appointment_id: Option<String>,
pub warnings: Option<Vec<Warning>>,
pub errors: Option<Vec<Error>>,
}Expand description
SetAppointmentResponse : Response schema for the addAppointmentForServiceJobByServiceJobId and rescheduleAppointmentForServiceJobByServiceJobId operations.
Fields
appointment_id: Option<String>The appointment identifier.
warnings: Option<Vec<Warning>>A list of warnings returned in the sucessful execution response of an API request.
errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl SetAppointmentResponse
impl SetAppointmentResponse
sourcepub fn new() -> SetAppointmentResponse
pub fn new() -> SetAppointmentResponse
Response schema for the addAppointmentForServiceJobByServiceJobId and rescheduleAppointmentForServiceJobByServiceJobId operations.